==> eam-wshub-proxyclient-11.4-4-sources.jar: net/datastream/schemas/mp_results/mp7082_001/MP7082_GetStandardWorkOrder_001_Result.java <==

package net.datastream.schemas.mp_results.mp7082_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.standardworkorder_001.StandardWorkOrder;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_entities/StandardWorkOrder_001}StandardWorkOrder"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP7082_GetStandardWorkOrder_001_Result")
public class MP7082_GetStandardWorkOrder_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP7082_GetStandardWorkOrder_001_Result.ResultData resultData;

    /**
     * Obtient la valeur de la propriété resultData.
     * 
     * @return
     *     possible object is
     *     {@link MP7082_GetStandardWorkOrder_001_Result.ResultData }
     *     
     */
    public MP7082_GetStandardWorkOrder_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Définit la valeur de la propriété resultData.
     * 
     * @param value
     *     allowed object is
     *     {@link MP7082_GetStandardWorkOrder_001_Result.ResultData }
     *     
     */
    public void setResultData(MP7082_GetStandardWorkOrder_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Classe Java pour anonymous complex type.
     * 
     * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_entities/StandardWorkOrder_001}StandardWorkOrder"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "standardWorkOrder"
    })
    public static class ResultData {

        @XmlElement(name = "StandardWorkOrder", namespace = "http://schemas.datastream.net/MP_entities/StandardWorkOrder_001", required = true)
        protected StandardWorkOrder standardWorkOrder;

        /**
         * Obtient la valeur de la propriété standardWorkOrder.
         * 
         * @return
         *     possible object is
         *     {@link StandardWorkOrder }
         *     
         */
        public StandardWorkOrder getStandardWorkOrder() {
            return standardWorkOrder;
        }

        /**
         * Définit la valeur de la propriété standardWorkOrder.
         * 
         * @param value
         *     allowed object is
         *     {@link StandardWorkOrder }
         *     
         */
        public void setStandardWorkOrder(StandardWorkOrder value) {
            this.standardWorkOrder = value;
        }

    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_results/mp7082_001/MP7082_GetStandardWorkOrder_001_Result.java <==

package net.datastream.schemas.mp_results.mp7082_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_entities.standardworkorder_001.StandardWorkOrder;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="ResultData">
 *           &lt;complexType>
 *             &lt;complexContent>
 *               &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *                 &lt;sequence>
 *                   &lt;element ref="{http://schemas.datastream.net/MP_entities/StandardWorkOrder_001}StandardWorkOrder"/>
 *                 &lt;/sequence>
 *               &lt;/restriction>
 *             &lt;/complexContent>
 *           &lt;/complexType>
 *         &lt;/element>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "resultData"
})
@XmlRootElement(name = "MP7082_GetStandardWorkOrder_001_Result")
public class MP7082_GetStandardWorkOrder_001_Result {

    @XmlElement(name = "ResultData", required = true)
    protected MP7082_GetStandardWorkOrder_001_Result.ResultData resultData;

    /**
     * Gets the value of the resultData property.
     * 
     * @return
     *     possible object is
     *     {@link MP7082_GetStandardWorkOrder_001_Result.ResultData }
     *     
     */
    public MP7082_GetStandardWorkOrder_001_Result.ResultData getResultData() {
        return resultData;
    }

    /**
     * Sets the value of the resultData property.
     * 
     * @param value
     *     allowed object is
     *     {@link MP7082_GetStandardWorkOrder_001_Result.ResultData }
     *     
     */
    public void setResultData(MP7082_GetStandardWorkOrder_001_Result.ResultData value) {
        this.resultData = value;
    }


    /**
     * <p>Java class for anonymous complex type.
     * 
     * <p>The following schema fragment specifies the expected content contained within this class.
     * 
     * <pre>
     * &lt;complexType>
     *   &lt;complexContent>
     *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
     *       &lt;sequence>
     *         &lt;element ref="{http://schemas.datastream.net/MP_entities/StandardWorkOrder_001}StandardWorkOrder"/>
     *       &lt;/sequence>
     *     &lt;/restriction>
     *   &lt;/complexContent>
     * &lt;/complexType>
     * </pre>
     * 
     * 
     */
    @XmlAccessorType(XmlAccessType.FIELD)
    @XmlType(name = "", propOrder = {
        "standardWorkOrder"
    })
    public static class ResultData {

        @XmlElement(name = "StandardWorkOrder", namespace = "http://schemas.datastream.net/MP_entities/StandardWorkOrder_001", required = true)
        protected StandardWorkOrder standardWorkOrder;

        /**
         * Gets the value of the standardWorkOrder property.
         * 
         * @return
         *     possible object is
         *     {@link StandardWorkOrder }
         *     
         */
        public StandardWorkOrder getStandardWorkOrder() {
            return standardWorkOrder;
        }

        /**
         * Sets the value of the standardWorkOrder property.
         * 
         * @param value
         *     allowed object is
         *     {@link StandardWorkOrder }
         *     
         */
        public void setStandardWorkOrder(StandardWorkOrder value) {
            this.standardWorkOrder = value;
        }

    }

}
